@@ -164,7 +164,7 @@ def main() -> None:
     print(f"  - Converged: {result.converged}")
     print(f"  - Factors: {result.Z.shape[1]} (state dimension: {result.Z.shape[1]})")
     if hasattr(result, 'loglik') and result.loglik is not None:
-        loglik_val = result.loglik[-1] if isinstance(result.loglik, (list, np.ndarray)) else result.loglik
+        loglik_val = result.loglik
         if loglik_val is not None and np.isfinite(loglik_val):
             print(f"  - Final log-likelihood: {loglik_val:.2f}")
 
@@ -179,13 +179,13 @@ def main() -> None:
     last_date = pd.to_datetime(Time[-1])
     try:
         forecast_dates = pd.date_range(
-            start=last_date + pd.tseries.frequencies.to_offset('M'),
-            periods=args.forecast_horizon, freq='M'
+            start=last_date + pd.tseries.frequencies.to_offset('ME'),
+            periods=args.forecast_horizon, freq='ME'
         )
     except Exception:
         forecast_dates = pd.date_range(
             start=last_date + pd.Timedelta(days=30),
-            periods=args.forecast_horizon, freq='M'
+            periods=args.forecast_horizon, freq='ME'
         )
     print(f"✓ Forecast complete:")
     print(f"  - Horizon: {args.forecast_horizon} periods")
